@@ -8,6 +8,7 @@ from typing import Any, Dict, List, Mapping, MutableSequence, Optional, Union, c
 from urllib.parse import urlparse
 
 import pkg_resources  # part of setuptools
+from rdflib import __version__ as rdflib_version
 from rdflib.parser import Parser
 from rdflib.plugin import register
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
@@ -17,9 +18,10 @@ from .avro.schema import SchemaParseException
 from .exceptions import ValidationException, to_one_line_messages
 from .makedoc import makedoc
 from .ref_resolver import Loader, file_uri
-from .utils import json_dumps
+from .utils import json_dump, stdout
 
-register("json-ld", Parser, "rdflib_jsonld.parser", "JsonLDParser")
+if int(rdflib_version.split(".")[0]) < 6:
+    register("json-ld", Parser, "rdflib_jsonld.parser", "JsonLDParser")
 _logger = logging.getLogger("salad")
 
 
@@ -30,13 +32,11 @@ def printrdf(
     sr: str,
 ) -> None:
     g = jsonld_context.makerdf(workflow, wf, ctx)
-    print(g.serialize(format=sr, encoding="utf-8").decode("utf-8"))
+    g.serialize(destination=stdout(), format=sr)
 
 
-def main(argsl: Optional[List[str]] = None) -> int:
-    if argsl is None:
-        argsl = sys.argv[1:]
-
+def arg_parser() -> argparse.ArgumentParser:
+    """Build the argument parser."""
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "--rdf-serializer",
@@ -94,7 +94,8 @@ def main(argsl: Optional[List[str]] = None) -> int:
         "--codegen",
         type=str,
         metavar="language",
-        help="Generate classes in target language, currently supported: python, java",
+        help="Generate classes in target language, currently supported: "
+        "python, java, typescript",
     )
 
     parser.add_argument(
@@ -112,6 +113,31 @@ def main(argsl: Optional[List[str]] = None) -> int:
         help="Directory of example documents for test case generation (Java only).",
     )
 
+    parser.add_argument(
+        "--codegen-package",
+        type=str,
+        metavar="dotted.package",
+        default=None,
+        help="Optional override of the package name which is other derived "
+        "from the base URL (Java only).",
+    ),
+
+    parser.add_argument(
+        "--codegen-copyright",
+        type=str,
+        metavar="copyright_string",
+        default=None,
+        help="Optional copyright of the input schema.",
+    ),
+
+    parser.add_argument(
+        "--codegen-parser-info",
+        metavar="parser_info",
+        type=str,
+        default=None,
+        help="Optional parser name which is accessible via resulted parser API (Python only)",
+    )
+
     exgroup.add_argument(
         "--print-oneline",
         action="store_true",
@@ -163,7 +189,18 @@ def main(argsl: Optional[List[str]] = None) -> int:
         "--brand", help="Use with --print-doc, set the 'brand' text in nav bar"
     )
     parser.add_argument(
-        "--brandlink", help="Use with --print-doc, set the link for 'brand' in nav bar"
+        "--brandlink",
+        help="Use with --print-doc, set the link for 'brand' in nav bar",
+    )
+    parser.add_argument(
+        "--brandstyle",
+        help="Use with --print-doc, HTML code to link to an external style sheet",
+    )
+    parser.add_argument(
+        "--brandinverse",
+        default=False,
+        action="store_true",
+        help="Use with --print-doc",
     )
     parser.add_argument(
         "--primtype",
@@ -176,11 +213,17 @@ def main(argsl: Optional[List[str]] = None) -> int:
     parser.add_argument(
         "--version", "-v", action="store_true", help="Print version", default=None
     )
+    return parser
 
-    args = parser.parse_args(argsl)
+
+def main(argsl: Optional[List[str]] = None) -> int:
+    if argsl is None:
+        argsl = sys.argv[1:]
+
+    args = arg_parser().parse_args(argsl)
 
     if args.version is None and args.schema is None:
-        print("{}: error: too few arguments".format(sys.argv[0]))
+        print(f"{sys.argv[0]}: error: too few arguments.")
         return 1
 
     if args.quiet:
@@ -191,7 +234,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
     pkg = pkg_resources.require("schema_salad")
     if pkg:
         if args.version:
-            print("{} Current version: {}".format(sys.argv[0], pkg[0].version))
+            print(f"{sys.argv[0]} Current version: {pkg[0].version}")
             return 0
         else:
             _logger.info("%s Current version: %s", sys.argv[0], pkg[0].version)
@@ -232,16 +275,28 @@ def main(argsl: Optional[List[str]] = None) -> int:
         return 1
 
     if args.print_doc:
-        makedoc(args)
+        makedoc(
+            sys.stdout,
+            args.schema,
+            args.redirect,
+            args.only,
+            args.brand,
+            args.brandlink,
+            args.primtype,
+            args.brandstyle,
+            args.brandinverse,
+        )
         return 0
 
     # Optionally print the schema after ref resolution
     if not args.document and args.print_pre:
-        print(json_dumps(schema_doc, indent=4))
+        json_dump(schema_doc, fp=sys.stdout, indent=4, default=str)
         return 0
 
     if not args.document and args.print_index:
-        print(json_dumps(list(metaschema_loader.idx.keys()), indent=4))
+        json_dump(
+            list(metaschema_loader.idx.keys()), fp=sys.stdout, indent=4, default=str
+        )
         return 0
 
     # Validate the schema document against the metaschema
@@ -261,7 +316,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
         (schema_ctx, rdfs) = jsonld_context.salad_to_jsonld_context(schema_doc, metactx)
     else:
         raise ValidationException(
-            "Expected a CommentedSeq, got {}: {}.".format(type(schema_doc), schema_doc)
+            f"Expected a CommentedSeq, got {type(schema_doc)}: {schema_doc}."
         )
 
     # Create the loader that will be used to load the target document.
@@ -275,6 +330,9 @@ def main(argsl: Optional[List[str]] = None) -> int:
             document_loader,
             target=args.codegen_target,
             examples=args.codegen_examples,
+            package=args.codegen_package,
+            copyright=args.codegen_copyright,
+            parser_info=args.codegen_parser_info,
         )
         return 0
 
@@ -292,7 +350,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
                 exc_info=((type(err), err, None) if args.debug else None),
             )
             if args.print_avro:
-                print(json_dumps(avsc_obj, indent=4))
+                json_dump(avsc_obj, fp=sys.stdout, indent=4, default=str)
             return 1
     else:
         _logger.error("Schema `%s` must be a list.", args.schema)
@@ -300,22 +358,22 @@ def main(argsl: Optional[List[str]] = None) -> int:
 
     # Optionally print Avro-compatible schema from schema
     if args.print_avro:
-        print(json_dumps(avsc_obj, indent=4))
+        json_dump(avsc_obj, fp=sys.stdout, indent=4, default=str)
         return 0
 
     # Optionally print the json-ld context from the schema
     if args.print_jsonld_context:
         j = {"@context": schema_ctx}
-        print(json_dumps(j, indent=4, sort_keys=True))
+        json_dump(j, fp=sys.stdout, indent=4, sort_keys=True, default=str)
         return 0
 
     # Optionally print the RDFS graph from the schema
     if args.print_rdfs:
-        print(rdfs.serialize(format=args.rdf_serializer).decode("utf-8"))
+        rdfs.serialize(destination=stdout(), format=args.rdf_serializer)
         return 0
 
     if args.print_metadata and not args.document:
-        print(json_dumps(schema_metadata, indent=4))
+        json_dump(schema_metadata, fp=sys.stdout, indent=4, default=str)
         return 0
 
     if args.print_inheritance_dot:
@@ -349,11 +407,13 @@ def main(argsl: Optional[List[str]] = None) -> int:
 
     # Optionally print the document after ref resolution
     if args.print_pre:
-        print(json_dumps(document, indent=4))
+        json_dump(document, fp=sys.stdout, indent=4, default=str)
         return 0
 
     if args.print_index:
-        print(json_dumps(list(document_loader.idx.keys()), indent=4))
+        json_dump(
+            list(document_loader.idx.keys()), fp=sys.stdout, indent=4, default=str
+        )
         return 0
 
     # Validate the user document against the schema
@@ -380,7 +440,7 @@ def main(argsl: Optional[List[str]] = None) -> int:
             return 1
 
     if args.print_metadata:
-        print(json_dumps(doc_metadata, indent=4))
+        json_dump(doc_metadata, fp=sys.stdout, indent=4, default=str)
         return 0
 
     print(f"Document `{args.document}` is valid")
