@@ -7,11 +7,11 @@ import sys
 import tempfile
 from typing import Union
 
-import pytest  # type: ignore
-from _pytest.fixtures import FixtureRequest  # type: ignore
+import pytest
+from _pytest.fixtures import FixtureRequest
 from requests import Session
-
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
+
 from schema_salad.exceptions import ValidationException
 from schema_salad.fetcher import DefaultFetcher
 from schema_salad.ref_resolver import Loader, file_uri
@@ -25,11 +25,11 @@ def is_fs_case_sensitive(
         return not os.path.exists(tmp_file.name.lower())
 
 
-@pytest.fixture  # type: ignore
+@pytest.fixture
 def tmp_dir_fixture(request: FixtureRequest) -> str:
     d = tempfile.mkdtemp()
 
-    @request.addfinalizer  # type: ignore
+    @request.addfinalizer
     def teardown() -> None:
         shutil.rmtree(d)
 
@@ -71,7 +71,7 @@ def test_Loader_initialisation_disable_doc_cache(tmp_dir_fixture: str) -> None:
     assert isinstance(loader.session, Session)
 
 
-@pytest.mark.skipif(sys.platform != "win32", reason="Only for win32")  # type: ignore
+@pytest.mark.skipif(sys.platform != "win32", reason="Only for win32")
 def test_DefaultFetcher_urljoin_win32(tmp_dir_fixture: str) -> None:
     # Ensure HOME is set.
     os.environ["HOME"] = tmp_dir_fixture
@@ -226,7 +226,7 @@ def test_attachments() -> None:
 
     l1 = Loader({})
     r1, _ = l1.resolve_ref(furi)
-    with open(path, "rt") as f:
+    with open(path) as f:
         content = f.read()
         assert {"foo": "bar", "baz": content, "quux": content} == r1
 
@@ -246,6 +246,16 @@ def test_attachments() -> None:
 
     l3 = Loader({}, allow_attachments=aa2)
     r3, _ = l3.resolve_ref(furi)
-    with open(path, "rt") as f:
+    with open(path) as f:
         content = f.read()
         assert {"foo": "bar", "baz": content, "quux": content} == r3
+
+
+def test_check_exists_follows_redirects() -> None:
+    fetcher = DefaultFetcher({}, Session())
+    # This tests that the redirect from http to https doesn't cause a
+    # false positive, this URL doesn't exist and it should return
+    # False because if it follows the redirect it'll get a 404.  Tests
+    # for previous bug where allow_redirects wasn't set and as a
+    # result it would return True even though the result was 3xx.
+    assert not fetcher.check_exists("http://commonwl.org/does/not/exist")
