@@ -17,11 +17,11 @@ from typing import (
 
 import pkg_resources
 
-from . import schema, _logger
+from . import _logger, schema
 from .codegen_base import CodeGenBase, TypeDef
 from .exceptions import SchemaException
-from .schema import shortname
 from .java_codegen import _ensure_directory_and_write, _safe_makedirs
+from .schema import shortname
 
 
 def doc_to_doc_string(doc: Optional[str], indent_level: int = 0) -> str:
@@ -495,14 +495,22 @@ export enum {enum_name} {{
                         doc_str=doc_to_doc_string(doc, indent_level=1)
                     )
                 )
-            f.write(
-                "  {safename}{optionalstring}: {type}\n".format(
-                    safename=safename,
-                    type=fieldtype.instance_type,
-                    optionalstring=optionalstring,
+            if fieldname == "class":
+                f.write(
+                    "  {safename}{optionalstring}: {type}\n".format(
+                        safename=safename,
+                        type=fieldtype.instance_type,
+                        optionalstring="?",
+                    )
+                )
+            else:
+                f.write(
+                    "  {safename}{optionalstring}: {type}\n".format(
+                        safename=safename,
+                        type=fieldtype.instance_type,
+                        optionalstring=optionalstring,
+                    )
                 )
-            )
-
         if self.current_class_is_abstract:
             return
 
@@ -525,13 +533,22 @@ export enum {enum_name} {{
                 )
             )
         if fieldname == "class":
-            self.current_constructor_signature.write(
-                ", {safename} = {type}.{val}".format(
-                    safename=safename,
-                    type=fieldtype.instance_type,
-                    val=self.current_class.replace("-", "_").replace(".", "_").upper(),
+            if fieldtype.instance_type == "string":
+                self.current_constructor_signature.write(
+                    ", {safename} = '{val}'".format(
+                        safename=safename, val=self.current_class
+                    )
+                )
+            else:
+                self.current_constructor_signature.write(
+                    ", {safename} = {type}.{val}".format(
+                        safename=safename,
+                        type=fieldtype.instance_type,
+                        val=self.current_class.replace("-", "_")
+                        .replace(".", "_")
+                        .upper(),
+                    )
                 )
-            )
         else:
             self.current_constructor_signature.write(
                 ", {safename}".format(
@@ -720,13 +737,16 @@ export enum {enum_name} {{
         )
 
     def epilogue(self, root_loader: TypeDef) -> None:
+
         """Trigger to generate the epilouge code."""
         pd = "This project contains TypeScript objects and utilities "
         pd = pd + ' auto-generated by <a href=\\"https://github.com/'
         pd = pd + 'common-workflow-language/schema_salad\\">Schema Salad</a>'
         pd = pd + " for parsing documents corresponding to the "
         pd = pd + str(self.base_uri) + " schema."
-        generated_class_imports = ",\n  ".join(self.record_types)
+
+        sorted_record_types = sorted(self.record_types)
+        generated_class_imports = ",\n  ".join(sorted_record_types)
         template_vars: MutableMapping[str, str] = dict(
             project_name=self.package,
             version="0.0.1-SNAPSHOT",
@@ -767,8 +787,9 @@ export enum {enum_name} {{
                     collected_type.name, collected_type.init
                 )
 
+        sorted_modules = sorted(self.modules)
         internal_module_exports = "\n".join(
-            f"export * from '../{f}'" for f in self.modules
+            f"export * from '../{f}'" for f in sorted_modules
         )
 
         example_tests = ""
